@@ -78,7 +78,7 @@ class AzureMLLunaUtils(BaseLunaUtils):
         model = Model(ws, self._args.predecessorOperationId)
         myenv = Environment.from_conda_specification('scoring', self.luna_config['conda_env'])
 
-        inference_config = InferenceConfig(entry_script=self.luna_config['code']['score'], source_directory = os.getcwd(), environment=myenv)
+        inference_config = InferenceConfig(entry_script=self.luna_config['code']['inference_entry_script'], source_directory = os.getcwd(), environment=myenv)
 
         deployment_config = self.GetDeploymentConfig(
             tags={'userId': self._args.userId, 
